@@ -153,6 +153,8 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      * @endcode
      *
      * @author Kevin Krammer <kevin.krammer@gmx.at>
+     *
+     * @deprecated Use ObserverV2 instead
      */
     class AKONADI_EXPORT Observer  // krazy:exclude=dpointer
     {
@@ -207,6 +209,67 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
         virtual void collectionRemoved( const Akonadi::Collection &collection );
     };
 
+    /**
+     * BC extension of Observer with support for monitoring item and collection moves.
+     * Use this one instead of Observer.
+     *
+     * @since 4.4
+     */
+    class AKONADI_EXPORT ObserverV2 : public Observer  // krazy:exclude=dpointer
+    {
+      public:
+        using Observer::collectionChanged;
+
+        /**
+         * Reimplement to handle item moves.
+         * When using this class in combination with Akonadi::ResourceBase, inter-resource
+         * moves are handled internally already and the corresponding  add or delete method
+         * is called instead.
+         *
+         * @param item The moved item.
+         * @param collectionSource The collection the item has been moved from.
+         * @param collectionDestination The collection the item has been moved to.
+         */
+        virtual void itemMoved( const Akonadi::Item &item, const Akonadi::Collection &collectionSource,
+                                const Akonadi::Collection &collectionDestination );
+
+        /**
+         * Reimplement to handle item linking.
+         * This is only relevant for virtual resources.
+         * @param item The linked item.
+         * @param collection The collection the item is linked to.
+         */
+        virtual void itemLinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
+
+        /**
+         * Reimplement to handle item unlinking.
+         * This is only relevant for virtual resources.
+         * @param item The unlinked item.
+         * @param collection The collection the item is unlinked from.
+         */
+        virtual void itemUnlinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
+
+        /**
+         * Reimplement to handle collection moves.
+         * When using this class in combination with Akonadi::ResourceBase, inter-resource
+         * moves are handled internally already and the corresponding  add or delete method
+         * is called instead.
+         *
+         * @param collection The moved collection.
+         * @param source The previous parent collection.
+         * @param destination The new parent collection.
+         */
+        virtual void collectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &collectionSource,
+                                      const Akonadi::Collection &collectionDestination );
+
+        /**
+         * Reimplement to handle changes to existing collections.
+         * @param collection The changed collection.
+         * @param partIdentifiers The identifiers of the collection parts that has been changed.
+         */
+        virtual void collectionChanged( const Akonadi::Collection &collection, const QSet<QByteArray> &changedAttributes );
+    };
+
     /**
      * This enum describes the different states the
      * agent can be in.
@@ -284,7 +347,11 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      * This method is called whenever the agent shall show its configuration dialog
      * to the user. It will be automatically called when the agent is started for
      * the first time.
+     *
      * @param windowId The parent window id.
+     *
+     * @note If the method is reimplemented it has to emit the configurationDialogAccepted()
+     *       or configurationDialogRejected() signals depending on the users choice.
      */
     virtual void configure( WId windowId );
 
@@ -309,6 +376,9 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     /**
      * This method is called when the agent is removed from
      * the system, so it can do some cleanup stuff.
+     *
+     * @note If you reimplement this in a subclass make sure
+     *       to call this base implementation at the end.
      */
     virtual void cleanup();
 
@@ -376,7 +446,17 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     void error( const QString& message );
 
     /**
-     * Emitted if another application has changed the agents configuration remotely
+     * Emitted when another application has remotely asked the agent to abort
+     * its current operation.
+     * Connect to this signal if your agent supports abortion. After aborting
+     * and cleaning up, agents should return to Idle status.
+     *
+     * @since 4.4
+     */
+    void abortRequested();
+
+    /**
+     * Emitted if another application has changed the agent's configuration remotely
      * and called AgentInstance::reconfigure().
      *
      * @since 4.2
@@ -390,6 +470,26 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      */
     void onlineChanged( bool b );
 
+    /**
+     * This signal is emitted whenever the user has accepted the configuration dialog.
+     *
+     * @note Implementors of agents/resources are responsible to emit this signal if
+     *       the agent/resource reimplements configure().
+     *
+     * @since 4.4
+     */
+    void configurationDialogAccepted();
+
+    /**
+     * This signal is emitted whenever the user has rejected the configuration dialog.
+     *
+     * @note Implementors of agents/resources are responsible to emit this signal if
+     *       the agent/resource reimplements configure().
+     *
+     * @since 4.4
+     */
+    void configurationDialogRejected();
+
   protected:
     /**
      * Creates an agent base.
@@ -464,6 +564,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     static int init( AgentBase *r );
 
     // D-Bus interface stuff
+    void abort();
     void reconfigure();
     void quit();
 
