@@ -41,11 +41,13 @@
 #include <QtGui/QClipboard>
 #include <QtGui/QStandardItemModel>
 #include <QtSql/QSqlDatabase>
+#include <QtSql/QSqlError>
 
 // @cond PRIVATE
 
 #define AKONADI_CONTROL_SERVICE QLatin1String("org.freedesktop.Akonadi.Control")
 #define AKONADI_SERVER_SERVICE QLatin1String("org.freedesktop.Akonadi")
+#define AKONADI_SEARCH_SERVICE QLatin1String("org.kde.nepomuk.services.nepomukqueryservice")
 
 using namespace Akonadi;
 
@@ -131,12 +133,19 @@ void SelfTestDialog::selectionChanged(const QModelIndex &index )
 
 void SelfTestDialog::runTests()
 {
+  const QString driver = serverSetting( QLatin1String("General"), "Driver", QLatin1String("QMYSQL") ).toString();
   testSQLDriver();
-  testMySQLServer();
-  testMySQLServerLog();
-  testMySQLServerConfig();
+  if (driver == QLatin1String( "QPSQL" )) {
+    testPSQLServer();
+  }
+  else {
+    testMySQLServer();
+    testMySQLServerLog();
+    testMySQLServerConfig();
+  }
   testAkonadiCtl();
   testServerStatus();
+  testSearchStatus();
   testProtocolVersion();
   testResources();
   testServerLog();
@@ -177,16 +186,18 @@ void SelfTestDialog::testSQLDriver()
 {
   const QString driver = serverSetting( QLatin1String("General"), "Driver", QLatin1String("QMYSQL") ).toString();
   const QStringList availableDrivers = QSqlDatabase::drivers();
-  const KLocalizedString details = ki18n( "The QtSQL driver '%1' is required by your current Akonadi server configuration.\n"
+  const KLocalizedString detailsOk = ki18n( "The QtSQL driver '%1' is required by your current Akonadi server configuration and was found on your system." )
+      .subs( driver );
+  const KLocalizedString detailsFail = ki18n( "The QtSQL driver '%1' is required by your current Akonadi server configuration.\n"
       "The following drivers are installed: %2.\n"
       "Make sure the required driver is installed." )
       .subs( driver )
       .subs( availableDrivers.join( QLatin1String(", ") ) );
   QStandardItem *item = 0;
   if ( availableDrivers.contains( driver ) )
-    item = report( Success, ki18n( "Database driver found." ), details );
+    item = report( Success, ki18n( "Database driver found." ), detailsOk );
   else
-    item = report( Error, ki18n( "Database driver not found." ), details );
+    item = report( Error, ki18n( "Database driver not found." ), detailsFail );
   item->setData( XdgBaseDirs::akonadiServerConfigFile( XdgBaseDirs::ReadWrite ), FileIncludeRole );
 }
 
@@ -329,6 +340,32 @@ void SelfTestDialog::testMySQLServerConfig()
   }
 }
 
+void SelfTestDialog::testPSQLServer()
+{
+  const QString dbname = serverSetting( QLatin1String( "QPSQL" ), "Name", QLatin1String( "akonadi" )).toString();
+  const QString hostname = serverSetting( QLatin1String( "QPSQL" ), "Host", QLatin1String( "localhost" )).toString();
+  const QString username = serverSetting( QLatin1String( "QPSQL" ), "User", QLatin1String( "akonadi" )).toString();
+  const QString password = serverSetting( QLatin1String( "QPSQL" ), "Password", QLatin1String( "akonadi" )).toString();
+  const int port = serverSetting( QLatin1String( "QPSQL" ), "Port", 5432).toInt();
+
+  QSqlDatabase db = QSqlDatabase::addDatabase( QLatin1String( "QPSQL" ) );
+  db.setHostName( hostname );
+  db.setDatabaseName( dbname );
+  db.setUserName( username );
+  db.setPassword( password );
+  db.setPort( port );
+
+  if ( !db.open() ) {
+    const KLocalizedString details = ki18n( db.lastError().text().toLatin1() );
+    report( Error, ki18n( "Cannot connect to PostgreSQL server." ),  details);
+  }
+  else {
+    report( Success, ki18n( "PostgreSQL server found." ),
+                   ki18n( "The PostgreSQL server was found and connection is working."));
+  }
+  db.close();
+}
+
 void SelfTestDialog::testAkonadiCtl()
 {
   const QString path = KStandardDirs::findExe( QLatin1String("akonadictl") );
@@ -372,6 +409,39 @@ void SelfTestDialog::testServerStatus()
   }
 }
 
+void SelfTestDialog::testSearchStatus()
+{
+  bool searchAvailable = false;
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AKONADI_SEARCH_SERVICE ) ) {
+    searchAvailable = true;
+    report( Success, ki18n( "Nepomuk search service registered at D-Bus." ),
+                   ki18n( "The Nepomuk search service is registered at D-Bus which typically indicates it is operational." ) );
+  } else {
+    report( Error, ki18n( "Nepomuk search service not registered at D-Bus." ),
+                   ki18n( "The Nepomuk search service is not registered at D-Bus which typically means it was not started "
+                          "or encountered a fatal error during startup."  ) );
+  }
+
+  if ( searchAvailable ) {
+    // check which backend is used
+    QDBusInterface interface( QLatin1String( "org.kde.NepomukStorage" ), QLatin1String( "/nepomukstorage" ) );
+    const QDBusReply<QString> reply = interface.call( QLatin1String( "usedSopranoBackend" ) );
+    if ( reply.isValid() ) {
+      const QString name = reply.value();
+
+      // put blacklisted backends here
+      if ( name.contains( QLatin1String( "redland" ) ) ) {
+        report( Error, ki18n( "Nepomuk search service uses inappropriate backend." ),
+                       ki18n( "The Nepomuk search service uses the '%1' backend, which is not "
+                              "recommended for use with Akonadi." ).subs( name ) );
+      } else {
+        report( Success, ki18n( "Nepomuk search service uses an appropriate backend. " ),
+                         ki18n( "The Nepomuk search service uses one of the recommended backends." ) );
+      }
+    }
+  }
+}
+
 void SelfTestDialog::testProtocolVersion()
 {
   if ( Internal::serverProtocolVersion() < 0 ) {
